@@ -85,7 +85,7 @@ setMethod("states","markovchain",
           }
 )
 
-#generic function to get the dim of a markovchain
+#generic function to get the dim of a markovchain and markovchainList
 
 setMethod("dim","markovchain", 
 		function(x) {
@@ -94,6 +94,18 @@ setMethod("dim","markovchain",
 		}
 )
 
+
+
+setMethod("dim","markovchainList", 
+          function(x) {
+            out<-length(x@markovchains)
+            return(out)
+          }
+)
+
+
+#function to set the validity of a markovchain object
+
 setValidity("markovchain",
             function(object) {
               check<-NULL
@@ -207,6 +219,18 @@ setMethod("show","markovchain", #metodo show
           }
 )
 
+setMethod("show", "markovchainList",
+          function(object){
+          for(i in 1:length(object@markovchains)) 
+          {
+            cat("Markovchain ",i,"\n")
+            show(object@markovchains[[i]])
+          }
+          }
+)
+
+setMethod("print","markovchainList",function(x) show(x))
+
 setMethod("print","markovchain", #metodo print
           function(x){
            object<-x
@@ -392,3 +416,20 @@ function(e1, e2) {
 	 return(out)
 }
 )
+
+
+#accesso diretto agli elementi della matrice/lista
+
+setMethod("[",
+          signature(x = "markovchain", i = "ANY", j = "ANY"),
+          function(x, i, j) {
+            out<-x@transitionMatrix[i,j]
+            return(out)
+          })
+
+setMethod("[[",
+          signature(x = "markovchainList", i = "ANY"),
+          function(x, i) {
+            out<-x@markovchains[[i]]
+            return(out)
+          })
